@@ -27,14 +27,50 @@
   ok("$d"    eq '1');
   ok("$e,$f" eq '2,3');
 
+  Floating point calculations on a triangle with angles of 22.5, 45, 112.5
+  degrees to determine whether two of the diameters of the nine point circle
+  are at right angles yield (on my computer) the following inconclusive result
+  when the dot product between the diameters is formed numerically:
+
+  my $o = 1;
+  my $a = sqrt($o/2);                              # X position of apex
+  my $b = $o - $a;                                 # Y position of apex
+  my $s = ($a*$a+$b*$b-$a)/2/$b;
+  my ($nx, $ny) = ($o/4 + $a/2, $b/2 - $s/2);      # Nine point centre
+  my ($px, $py) = ($o/2, 0);                       # Diameter from mid point
+  my ($qx, $qy) = ($o/2 + $a/2, $b/2);             # Diameter from mid point
+
+  my $d = ($px-$nx)*($qx-$nx)+($py-$ny)*($qy-$ny); # Dot product should be zero
+  print +($d == 0)||0, "\n$d\n";                   # Definitively zero if 1
+
+  # 0                                              # Not exactly zero
+  # -6.93889390390723e-18                          # Is this significant or not?
+
+  By contrast with Math::Algebra::Symbols I get the much more convincing:
+
+  my ($o, $i) = symbols(qw(1 i));                  # Units in x,y
+  my $a = sqrt($o/2);                              # X position of apex
+  my $b = $o - $a;                                 # Y position of apex
+  my $s = ($a*$a+$b*$b-$a)/2/$b;
+  my $n = $o/4 + $a/2 +$i*($b/2 - $s/2);           # Nine point centre
+  my $p = $o/2;                                    # Diameter from mid point
+  my $q = $o/2 + $a/2 +$i* $b/2;                   # Diameter from mid point
+
+  my $d = (($p-$n) ^ ($q-$n));                     # Dot product should be zero
+  print +($d == 0)||0, "\n$d\n";                   # Definitively zero if 1
+
+  # 1
+  # 17/32/(-2*sqrt(1/2)+3/2)-3/4/(-2*sqrt(1/2)+3/2)*sqrt(1/2)-7/16/(-sqrt(1/2)+1)
+  # +5/8/(-sqrt(1/2)+1)*sqrt(1/2)-1/8*sqrt(1/2)+1/16
+
 =head1 Description
 
   This package supplies a set of functions and operators to manipulate
   operator expressions algebraically using the familiar Perl syntax.
 
-  These expressions are constructed
-  from L</Symbols>, L</Operators>, and L</Functions>, and processed via
-  L</Methods>.  For examples, see: L</Examples>.
+  These expressions are constructed from L</Symbols>, L</Operators>, and
+  L</Functions>, and processed via L</Methods>.  For examples, see:
+  L</Examples>.
 
 =head2 Symbols
 
@@ -637,7 +673,7 @@ Example t/simplify2.t
 =cut
 
 package Math::Algebra::Symbols;
-$VERSION=1.25;
+$VERSION=1.26;
 use Math::Algebra::Symbols::Sum;
 use Carp;
 
@@ -833,9 +869,14 @@ END
   B<Symbols::Term> and thus behaves as a polynomial. Operations such as
   equation solving and differentiation are applied at this level.
 
-=head1 Author
+=head1 Installation
 
-  Philip R Brenan at B<PhilipRBrenan@gmail.com>
+ Standard Module::Build process for building and installing modules:
+
+   perl Build.PL
+   ./Build
+   ./Build test
+   ./Build install
 
 =head1 Copyright
 
